@@ -1,4 +1,4 @@
-__version__=0.3
+__version__=0.42
 
 ### Load the FairDetect Class
 import time
@@ -35,7 +35,7 @@ class Fairdetect:
         """
         print(data_bd.columns.values)
         data_bd.target_column = input("Please select target column")
-        if not(set(data[data_bd.target_column].unique())==set([0,1])):
+        if not(set(data_bd[data_bd.target_column].unique())==set([0,1])):
             raise ValueError('Only binary target variable')
         else:
             print("You choose wisely. Your target variable is:", data_bd.target_column)
@@ -43,7 +43,7 @@ class Fairdetect:
         return data_bd.target_column
     
     
-    def create_labels(self,sensitive):
+    def create_labels(self,sensitive,X_test):
         """
         Define labels for sensitive variable
         
@@ -76,7 +76,7 @@ class Fairdetect:
             #print(target_name)
         return(target_name)
     
-    def get_sensitive_col(self):
+    def get_sensitive_col(self,X_test):
         """
         Allows user to define the sensitive variable out of the columns available
         Checks if sensitive variable is Binary or not. Only binary sensitive variable accepted
@@ -92,7 +92,7 @@ class Fairdetect:
         print()
         return sens_col
     
-    def representation(self,X_test,y_test,sensitive,labels,predictions):
+    def representation(self,X_test,y_test,sensitive,labels,predictions,target_names):
         """
         Identifies representation bias for a relationship between the sensitive group and the target group
         
@@ -152,7 +152,7 @@ class Fairdetect:
             marker_color=['orange','blue'][i]),row=1,col=2)
 
         c, p, dof, expected = chi2_contingency(contigency_p)
-        cont_table = (tabulate(contigency_pct_p.T, headers=labels.values(), tablefmt='fancy_grid'))
+        cont_table = (tabulate(contigency_pct_p.T, headers=labels.values(),showindex= target_names.values(), tablefmt='fancy_grid'))
 
         return cont_table, sens_df, fig, p
         
@@ -366,7 +366,7 @@ class Fairdetect:
         """
         predictions = self.model.predict(self.X_test)
         target_names=self.create_targetname(predictions)
-        cont_table,sens_df,rep_fig,rep_p = self.representation(self.X_test,self.y_test,sensitive,labels,predictions)
+        cont_table,sens_df,rep_fig,rep_p = self.representation(self.X_test,self.y_test,sensitive,labels,predictions,target_names)
 
         print("REPRESENTATION")
         rep_fig.show()
